#
# spec file for package python-Whoosh
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Whoosh
Version:        2.7.4
Release:        10.3
Summary:        Pure-Python full text indexing, search, and spell checking library
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/whoosh-community/whoosh/
Source:         https://files.pythonhosted.org/packages/source/W/Whoosh/Whoosh-%{version}.tar.gz
# upstream in completely unrelated https://github.com/whoosh-community/whoosh/commit/b43e5a432109
Patch0:         pytest4.patch
# upstream in https://github.com/whoosh-community/whoosh/commit/f5a777572fb9
Patch1:         py2encoding.patch
# PATCH-FIX-UPSTREAM NullMatcherClass-hashable.patch gh#whoosh-community/whoosh#570 mcepl@suse.com
# NullMatcherClass needs __hash__ method as well for Sphinx4 compatiblity.
Patch2:         NullMatcherClass-hashable.patch
# PATCH-FIX-UPSTREAM docs-Update-intersphinx_mapping.patch gh#whoosh-community/whoosh#582
# fix intersphinx_mapping
Patch3:         docs-Update-intersphinx_mapping.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildArch:      noarch
# SECTION the testing dependencies
BuildRequires:  %{python_module pytest}
# /SECTION
%ifpython2
Provides:       python-whoosh = %{version}
Obsoletes:      python-whoosh < %{version}
%endif
%python_subpackages

%description
Whoosh is a pure-Python indexing and search library. It can be used
to add search functionality to applications and websites. Every part
of how Whoosh works can be extended or replaced to meet specific
needs.

%if 0%{?suse_version} > 1500
%package -n python-Whoosh-doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Provides:       %{python_module Whoosh-doc = %{version}}

%description -n python-Whoosh-doc
Whoosh is a pure-Python indexing and search library. It can be used
to add search functionality to applications and websites. Every part
of how Whoosh works can be extended or replaced to meet specific
needs.

This package contains the documentation.
%endif

%prep
%autosetup -p1 -n Whoosh-%{version}

# Fix CRLF->LF
sed -i -e 's/\r$//' docs/source/api/filedb/{filestore,filetables,structfile}.rst

%build
%python_build
sphinx-build -b html -d docs/build/doctrees docs/source docs/build/html

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF8
# test_list_corrector - depends on dict sorting thats in py3+ only
%pytest -k 'not test_list_corrector'

%files %{python_files}
%license LICENSE.txt
%doc README.txt
%{python_sitelib}/*

%if 0%{?suse_version} > 1500
%files -n python-Whoosh-doc
%license LICENSE.txt
%endif
%doc docs/build/html

%changelog
* Wed Sep  4 2024 Christoph G <foss@grueninger.de>
- Fix intersphinx mapping by adding
  docs-Update-intersphinx_mapping.patch
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- fix line endings
* Tue May  2 2023 Daniel Garcia <daniel.garcia@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Sun Apr 23 2023 Matej Cepl <mcepl@suse.com>
- Move documentation into the main package for SLE15
* Tue Apr  5 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1197830)
* Mon Jun 21 2021 Matej Cepl <mcepl@suse.com>
- Add NullMatcherClass-hashable.patch which adds __hash__
  method to NullMatcherClass, so that it works with Sphinx4
  (gh#whoosh-community/whoosh#570).
* Thu Jul 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with pytest4+ (both in git of upstream):
  * pytest4.patch
  * py2encoding.patch
- Use fdupes
- Update URL
- Make sure py2 tests are run too
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Jul 10 2017 jengelh@inai.de
- Ensure neutrality of description.
* Mon Jun 26 2017 tbechtold@suse.com
- convert to singlespec
- split -doc package
- use files.pythonhosted.org as Source url
- update to 2.7.4:
  * Changed version number to 2.7.0.
  * Added tag 2.7.0 for changeset 8abeb09483b9
  * Results.extend() didn't update the cached length.
  * Fixed VarBytesListColumn and FixedBytesListColumn.
  * Handle an empty queue exception in mpwriter.
  * Merging pull request with local commit.
  * Added test for storing tuples.
  * Remove caching decorator from VarBytesColumn reader.
  * Added test for has_deletions() after an optimization.
  * Try to avoid an UnboundLocalError in the DFA when MultiTerm.matcher() has
    an empty string.
  * Don't try to write a vector if the list of items is empty.
  * Implemented use of score_fn argument to NestedParent.
  * Don't cache query -> bitset, since this somehow prevents the Searcher from
    being collected.
  * Changed README docs link to point to readthedocs.org.
  * Change uses of dump[s]() to always use protocol 2 instead of -1
    ("use latest protocol") so indices created with Python 3.x are backwards
    compatible.
  * Fix the analyzer in test_vector_unicode() to not lowercase, since this
    makes the test fail on some Python versions.
  * Actually use the split_fn passed by the user. Not sure what happened here.
  * Handle pickled Schema objects that don't have a _subfields attribute.
  * Added fix and tests for calling expand_prefix() with unicode.
  * Fix short code for Swedish in language aliases.
  * Fix missing a consecutive token during highlighting
  * Added estimate_size() methods to SpanNear2.
  * Removed reference to "allfields" keyword argument.
  * Added tests/english-words.10.gz to manifest so it's included in the distribution.
  * Fix warnings in docs build.
  * BufferedWriter should call close() instead of commit() when exiting a context.
  * Reinstate fields.IDLIST's analyzer.
  * Change the version of my fork to be distinct from the base repo.
  * Backed out changeset 96255fc8ff17
  * A typo in `whoosh.fields.KEYWORD` documentation
  * Created new branch romanian-stemmer
  * Skip ISO-8859-1 suffixes on Unicode strings
  * Created new branch spanish-tokenizer
  * Add sanity check for Spanish stemmer
  * Fix sample highlight class
  * Reorder the self._tempstorage.destroy() in SegmentWriter._finish to
    before the lock is released
  * IOError from rmdir is ok if the error was ENOENT
  * Fix reporting of total count in FilterCollector, based on PR #63 by Jannon Frank.
  * Added a test for pickling a schema with a stemming analyzer.
  * Initial unfinished, massive checkin of next-gen architecture.
  * Fix forward-compatibility issue for Python 3.x.
  * Write offsets in VarBytesColumn when there are more than a certain number of rows.
  * Replaced porter stemming algorithm implementation with one based on the one in NLTK.
  * Add IDEA's .cache directory to hgignore.
  * Add IDEA's .cache directory to hgignore.
  * Remove docstring chickenscratch.
  * Fix test accidentally left with assert False at the end.
  * Removed accidentally committed debug prints.
  * Bumped version number for bugfix release.
  * Added tag 2.7.1 for changeset 1bd4b9792eed
  * Merging Bitbucket and local heads.
  * Bumped version number.
  * Added tag 2.7.2 for changeset f6bf123ac708
  * Fixed logic for checking if floats are all whole in encode_weights.
  * Change posting storage so the data from individual posts can be pulled
    out as raw bytes.
  * Fixed error in CommaSeparatedTokenizer.
  * Fixed import error.
  * Minor changes.
  * Updated VarBytesColumn to store offsets as well as lengths.
  * Added context protocol to Index class. Store TOC file name in object.
  * Switched to lighter-weight posting block format.
  * Forgot to check in pfor.py.
  * Reduced size of and references to whoosh.compat, in anticipation of
    using 3to2 for most things.
  * Remove (object) from class definitions, assuming 3to2 will take care of it.
  * Fixed problems from compat refactoring.
  * Fixed problem with calling leaf matcher methods on a MultiMatcher.
  * Don't encode bytes in _kws_to_query.
  * Removed typing annotations to prevent circular import.
  * Cleaned up filename generation/checking, added GC step to saving TOC.
  * Added header checks in terms and postings files.
  * Cleaned up storage cleanup, call it in SegmentWriter.cancel().
  * Added another except clause to catch TypeError, because that's what's raised
    if you try to pickle a function.
  * Fixed error that discarded vector metadata when merging segments.
  * Added ability to specify an analyzer in KEYWORD field constructor.
  * Bumped version number to 2.7.3.
  * Added tag 2.7.3 for changeset f5a1508e93fd
  * Added HyphenFilter to collapse hyphenated words into single tokens.
  * Have OrGroup.factory() return a real class instead of a function.
  * Bumped version number.
* Fri Apr 24 2015 cdenicolo@suse.com
- license update: BSD-2-Clause
  correct license ist BSD-2-Clause
* Wed Apr 22 2015 mcihar@suse.cz
- Update to 2.7.0:
  * Removed on-disk word graph implementation of spell checking in favor of much
    simpler and faster FSA implementation over the term file.
  * Many bug fixes.
  * Removed backwards compatibility with indexes created by versions prior to
    2.5. You may need to re-index if you are using an old index that hasn't been
    updated.
  * This is the last 2.x release before a major overhaul that will break backwards
    compatibility.
* Wed Jul 23 2014 mcihar@suse.cz
- Upgrate to 2.5.7 (no changelog provided)
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Oct  7 2013 mcihar@suse.cz
- build documentation during build
* Mon Oct  7 2013 mcihar@suse.cz
- now uses py.test instead of nose for testing
* Mon Oct  7 2013 mcihar@suse.cz
- Update to version 2.5.4
  + New index format
  + Better API for index creation
* Wed Jan 30 2013 saschpe@suse.de
- Update to version 2.4.1:
  + Fixes issues #242, #257, #261, #262, #263
- Renamed to python-Whoosh, obsoletes python-whoosh
- Install HTML documentation and LICENSE.txt
- Set SPDX-style license
- Run testsuite
* Fri Jun  8 2012 highwaystar.ru@gmail.com
- update to 2.4.0
- python3 package added
- a lot of spec improvements
* Mon Apr 16 2012 mcihar@suse.cz
- updated to 2.3.2
- make package noarch if possible
